/**
 * Copyright (c) 2013-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.probes.api.probes.macro;

import java.util.concurrent.ThreadPoolExecutor;

import org.ow2.petals.probes.api.exceptions.ProbeNotInitializedException;
import org.ow2.petals.probes.api.exceptions.ProbeNotStartedException;
import org.ow2.petals.probes.api.probes.Probe;

/**
 * A macro probe containing all probes needed to monitor an instance of the
 * thread pool {@link ThreadPoolExecutor}.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public interface ThreadPoolProbe extends Probe {

    /**
     * Set the thread pool to probe
     * 
     * @param threadPool
     *            the thread pool to probe
     */
    public void setThreadPool(final ThreadPoolExecutor threadPool);

    /**
     * @return The current max size of the thread pool.
     */
    public long getThreadPoolMaxSize();

    /**
     * @return The current min size of the thread pool
     */
    public long getThreadPoolMinSize();

    /**
     * @return The max number of active threads of the thread pool
     */
    public long getThreadPoolActiveThreadsMax() throws ProbeNotInitializedException;

    /**
     * @return The current number of active threads of the thread pool
     */
    public long getThreadPoolActiveThreadsCurrent() throws ProbeNotStartedException;

    /**
     * @return The max number of idle threads of the thread pool
     */
    public long getThreadPoolIdleThreadsMax() throws ProbeNotInitializedException;

    /**
     * @return The current number of idle threads of the thread pool
     */
    public long getThreadPoolIdleThreadsCurrent() throws ProbeNotStartedException;

    /**
     * @return The max number of enqueued tasks into the thread pool
     */
    public long getThreadPoolQueuedRequestsMax() throws ProbeNotInitializedException;

    /**
     * @return The current number of enqueued tasks into the thread pool
     */
    public long getThreadPoolQueuedRequestsCurrent() throws ProbeNotStartedException;

    /**
     * Realizes a measure of the thread pool:
     * <ul>
     * <li>current number of allocated threads,</li>
     * <li>current number of enqueued tasks.</li>
     * </ul>
     */
    public void pick() throws ProbeNotStartedException;

}
