/**
 * Copyright (c) 2012 EBMWebsourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.probes.api.sensor;

import org.ow2.petals.probes.api.probes.KeyedGaugeProbe;

/**
 * The sensor associated to a keyed gauge probe
 * 
 * @author Christophe DENEUX (PetalsLink)
 * 
 * @param <T>
 *            The type of measured values.
 * @param <S>
 *            The type of value to return to client probe
 */
public interface KeyedGaugeSensor<K, T, S> extends Sensor<T, S> {

	/**
	 * <p>
	 * Returns the instant value of the sensor, according to the asked key.
	 * </p>
	 * <p>
	 * <b>MUST</b> be thread safe.
	 * </p>
	 * 
	 * @return The instant value of the sensor.
	 */
	public T getInstantValue(final K key);
	
	/**
	 * <p>Free resources of the sensor.</p>
	 * <p>Invoked on startup and shutdown of a {@link KeyedGaugeProbe}</p>
	 */
	public void reset();
}