/**
 * Copyright (c) 2012 EBMWebsourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.probes.api.sensor;

/**
 * The sensor associated to a gauge probe
 * 
 * @author Christophe DENEUX (PetalsLink)
 * 
 * @param <T>
 *            The type of measured values.
 * @param <S>
 *            The type of value to return to client probe
 */
public interface Sensor<T, S> {

    /**
     * <p>
     * Convert a value of type &lt;T&gt; into a value of type &lt;S&gt;.
     * </p>
     * <p>
     * <b>MUST</b> be thread safe.
     * </p>
     * 
     * @param valueToConvert
     *            The value to convert.
     * @return The value of type &lt;T&gt; converted into a &lt;S&gt; value.
     */
    public S toExternalValue(final T valueToConvert);
}