/**
 * Copyright (c) 2012 EBMWebsourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.probes.api.probes;

import java.util.Arrays;
import java.util.LinkedList;

import junit.framework.TestCase;

import org.ow2.petals.probes.api.exceptions.NoResponseTimeException;

/**
 * Unit tests of {@link ResponseTimeRelativeValues}
 * 
 * @author Christophe DENEUX (PetalsLink)
 * 
 */

public class ResponseTimeRelativeValuesTestCase extends TestCase {

    /**
     * <p>
     * Check the computed relative response time values from a list that
     * contains an <b>EVEN</b> number of response times.
     * </p>
     */
    public void testConstructor_001() throws NoResponseTimeException {
        final LinkedList<Long> responseTimes = new LinkedList<Long>(Arrays.asList(new Long[] {
                100L, 200L, 300L, 400L, 500L, 700L, 900L, 1200L, 1500L, 2000L,
                101L, 201L, 301L, 401L, 501L, 701L, 901L, 1201L, 1501L, 2001L}));
        final ResponseTimeRelativeValues rtrv = new ResponseTimeRelativeValues(responseTimes);

        TestCase.assertEquals("The max value is wrong", 2001L, rtrv.getMax());
        TestCase.assertEquals("The avg value is wrong", 780L, rtrv.getAvg());
        TestCase.assertEquals("The min value is wrong", 100L, rtrv.getMin());
        TestCase.assertEquals("The 10-percentile value is wrong", 200L, rtrv.getPercent10());
        TestCase.assertEquals("The 50-percentile value is wrong", 700L, rtrv.getPercent50());
        TestCase.assertEquals("The 90-percentile value is wrong", 1501L, rtrv.getPercent90());
    }

    /**
     * <p>
     * Check the computed relative response time values from a list that
     * contains an <b>ODD</b> number of response times.
     * </p>
     */
    public void testConstructor_002() throws NoResponseTimeException {
        final LinkedList<Long> responseTimes = new LinkedList<Long>(Arrays.asList(new Long[] {
                100L, 200L, 300L, 400L, 500L, 700L, 900L, 1200L, 1500L, 2000L, 101L, 201L, 301L,
                401L, 501L, 701L, 901L, 1201L, 1501L, 2001L, 5001L }));
        final ResponseTimeRelativeValues rtrv = new ResponseTimeRelativeValues(responseTimes);

        TestCase.assertEquals("The max value is wrong", 5001L, rtrv.getMax());
        TestCase.assertEquals("The avg value is wrong", 981L, rtrv.getAvg());
        TestCase.assertEquals("The min value is wrong", 100L, rtrv.getMin());
        TestCase.assertEquals("The 10-percentile value is wrong", 200L, rtrv.getPercent10());
        TestCase.assertEquals("The 50-percentile value is wrong", 700L, rtrv.getPercent50());
        TestCase.assertEquals("The 90-percentile value is wrong", 2000L, rtrv.getPercent90());
    }

    /**
     * <p>
     * Check the computed relative response time values from a list that
     * contains no response time.
     * </p>
     */
    public void testConstructor_003() {
        final LinkedList<Long> responseTimes = new LinkedList<Long>();
        try {
            new ResponseTimeRelativeValues(responseTimes);
            TestCase.fail("The constructor should fail with NoResponseTimeException");
        } catch (final NoResponseTimeException e) {
            // NOP, it's the expected exception
        }
    }

    /**
     * <p>
     * Check the computed relative response time values from a list that
     * contains only one response time.
     * </p>
     */
    public void testConstructor_004() throws NoResponseTimeException {
        final LinkedList<Long> responseTimes = new LinkedList<Long>(
                Arrays.asList(new Long[] { 100L }));
        final ResponseTimeRelativeValues rtrv = new ResponseTimeRelativeValues(responseTimes);

        TestCase.assertEquals("The max value is wrong", 100L, rtrv.getMax());
        TestCase.assertEquals("The avg value is wrong", 100L, rtrv.getAvg());
        TestCase.assertEquals("The min value is wrong", 100L, rtrv.getMin());
        TestCase.assertEquals("The 10-percentile value is wrong", 100L, rtrv.getPercent10());
        TestCase.assertEquals("The 50-percentile value is wrong", 100L, rtrv.getPercent50());
        TestCase.assertEquals("The 90-percentile value is wrong", 100L, rtrv.getPercent90());
    }

}
